===============================
cascade
===============================

A Python library to assign river order to hydrometric networks

* Documentation: https://compassinformatics.github.io/cascade/

Features
--------

Two stream ordering algorithms:

* Strahler
* Shreve

Installation
------------

.. code-block:: bash

    pip install cascade-rivers
